@@ -3,11 +3,11 @@ use anyhow::{format_err, Result};
 mod common;
 mod core;
 mod extensions;
-mod metrics;
 mod payees;
+mod portal;
+mod profile;
 
 pub use common::FileStore;
-pub use metrics::Metrics;
 pub use payees::Payees;
 
 #[derive(
@@ -15,7 +15,8 @@ pub use payees::Payees;
 )]
 pub struct Config {
     pub core: core::Core,
-    pub metrics: metrics::Metrics,
+    pub portal: portal::Portal,
+    pub profile: profile::Parameters,
     pub extensions: extensions::Extensions,
 }
 
@@ -25,10 +26,12 @@ impl Config {
 
         return if core::is_match(name)? {
             Ok(core::set(&mut self.core, &name, &value)?)
+        } else if portal::is_match(name)? {
+            Ok(portal::set(&mut self.portal, &name, &value)?)
         } else if extensions::is_match(name)? {
             Ok(extensions::set(&mut self.extensions, &name, &value)?)
-        } else if metrics::is_match(name)? {
-            Ok(metrics::set(&mut self.metrics, &name, &value)?)
+        } else if profile::is_match(name)? {
+            Ok(profile::set(&mut self.profile, &name, &value)?)
         } else {
             Err(format_err!(name_error_message.clone()))
         };
@@ -39,10 +42,12 @@ impl Config {
 
         return if core::is_match(name)? {
             Ok(core::get(&self.core, &name)?)
+        } else if portal::is_match(name)? {
+            Ok(portal::get(&self.portal, &name)?)
         } else if extensions::is_match(name)? {
             Ok(extensions::get(&self.extensions, &name)?)
-        } else if metrics::is_match(name)? {
-            Ok(metrics::get(&self.metrics, &name)?)
+        } else if profile::is_match(name)? {
+            Ok(profile::get(&self.profile, &name)?)
         } else {
             Err(format_err!(name_error_message.clone()))
         };
